#!/bin/ksh
#
# Script Name:
#
#   ENS_EnsembleWait.ksh
#
# Usage:  
#
#   ENS_EnsembleWait.ksh $scriptdir $jobid $ensemble_dir \
#                      $logfile $email_target
#
#     $scriptdir     absolute path to these scripts
#     $jobid         LoadLeveler jobid to wait on
#     $ensemble_dir  top-level working directory
#     $logfile       full path to logfile
#     $email_target  where to send email if something fails
#
# Description:  
#
#   Wait on ensemble jobs to complete.  
#
# Dependencies:  
#
#   Since this script is intended to be called from a script called from cron, 
#   it has no dependencies on environment variables.  
#
#   Scripts called by this script must reside in the same directory as 
#   this script.  
#
# Author:  
#
#   Tom Henderson                          email:  hender@ucar.edu
#   NCAR, MMM Division                     voice:  303 497 1628
#   3450 Mitchell Lane                       fax:  303 497 8181
#   Boulder, Colorado 80301-2260 USA
#

set -u

# name of this script
self=$(/usr/bin/basename $0)

# load arguments
scriptdir=$1; shift
jobid=$1; shift
ensemble_dir=$1; shift
logfile=$1; shift
email_target=$1; shift

# explicitly load all shared functions
. ${scriptdir}/ENS_SharedFunctions.ksh
# explicitly set path
SetPath

# parse ensemble-wide config file
# GetMyConfig sets variables named ENS_CONFIG_*
GetMyConfig 0 $scriptdir $logfile $email_target

# turn on for debugging
if [[ $ENS_CONFIG_DEBUG = "TRUE" ]] ; then
  set -x
fi

# wait for jobs to finish...
AppendToLogFile "${self}:  waiting for ENS ensemble ..." \
  $self $scriptdir $logfile $email_target
${scriptdir}/wait_jobid.ksh $scriptdir $jobid $logfile $email_target

# $$$ TODO:  In a previous incarnation, this script checked for valid 
# $$$        results.  Maybe remove it now and call wait_jobid.ksh directly...

exit 0

