#!/bin/ksh

set -u

# name of this script
self=$(/usr/bin/basename $0)

# load arguments
scriptdir=$1; shift
maxensemble=$1; shift
ensemble_dir=$1; shift
ENS_ValidDate=$1; shift
logfile=$1; shift
email_target=$1; shift
config_tag=$1; shift

# explicitly load all shared functions
. ${scriptdir}/ENS_SharedFunctions.ksh
# explicitly set path
SetPath

# config
GetMyConfig 0 $scriptdir $logfile $email_target $config_tag

vList=$ENS_CONFIG_MeanSprVars
vArr=`echo $vList | sed s/,/\ /g`

# Find NCO executables
ncks_exe=$( which ncks )
ncea_exe=$( which ncea )
ncatted_exe=$( which ncatted )
ncap_exe=$( which ncap )
ncren_exe=$( which ncrename )
ncdiff_exe="$( which ncdiff ) -v $vList"

# no further if nco not available
if [[ ! $ncea_exe ]] ; then
 ErrorEmailExit "could not find NCO for postprocessing" ${self} $logfile $email_target ${ENS_JGEValidDate}
fi

# make output directory
if [[ -d Output_L1 ]] ; then
  /bin/rm -rf Output_L1
fi

mkdir Output_L1 || ErrorEmailExit "could not create L1 postprocessing directory Output_L1" ${self} $logfile $email_target ${ENS_JGEValidDate}

# loop over number of domains
thisdomain=1
until (( thisdomain > ENS_CONFIG_NumDomains )) ; do
  wrfdomain="d0${thisdomain}"
  # key each file list off the first ensemble member
  cd ${ensemble_dir}/Member1_rundir
  WRFFileNames=`ls wrfout_${wrfdomain}*`
  cd ${ensemble_dir}
  
  for WRFOutFileName in ${WRFFileNames[*]}; do
    MyFiles=`find ./ -name $WRFOutFileName`
    # compute mean
    $ncea_exe -O -o Output_L1/Mean_$WRFOutFileName $MyFiles
    $ncatted_exe -a description,,a,c,\ MEAN Output_L1/Mean_$WRFOutFileName

    # variance ov one variable at a time
    for vName in ${vArr[*]}; do
      # square the mean
      $ncap_exe -v -O -s "${vName}msq=$vName*$vName" -o ${vName}msq.nc Output_L1/Mean_$WRFOutFileName
      thismember=1
      for WRFOutFile in ${MyFiles[*]}; do
        # square each member
        $ncap_exe -v -O -s "${vName}sq=$vName*$vName" -o ${vName}_Member${thismember}.nc $WRFOutFile

      (( thismember += 1 ))
      done

      $ncea_exe -A -v ${vName}sq -o ${vName}msq.nc ${vName}_Member*
      $ncren_exe -v ${vName}sq,${vName}sqm ${vName}msq.nc
      $ncap_exe -O -v -s "${vName}=${vName}sqm-${vName}msq" -o tmp.nc ${vName}msq.nc
      $ncatted_exe -a description,,a,c,\ VARIANCE tmp.nc
      $ncks_exe -A -v ${vName} -o Output_L1/Var_$WRFOutFileName tmp.nc
    done
  done

  (( thisdomain += 1 ))
done

/bin/rm -f *.nc

return

