#!/bin/ksh
#
# wait_jobid.ksh scriptdir jobid logfile email_target
#  
#     $scriptdir     absolute path to these scripts
#     $jobid         id of job to wait on
#     $logfile       full path to logfile
#     $email_target  where to send email if something fails
#
#  Wait on job specified by jobid that was submitted using "llsubmit".  
#

set -u

# name of this script
self=$(/usr/bin/basename $0)

# load arguments
scriptdir=$1; shift
jobid=$1; shift
logfile=$1; shift
email_target=$1; shift

# explicitly load all shared functions
. ${scriptdir}/ENS_SharedFunctions.ksh
# explicitly set path
SetPath

# seconds between llq checks
llq_interval=2

#TBH:  Removed the "wait to queue" section since a job may finish quickly.  
#TBH:  This will fail if llsubmit returns before llq reports that the 
#TBH:  job just submitted is queued.  
#TBH:  Really need to use LoadLeveler job steps to queue the whole ensemble...  

#TBH  # need to check right away in case job finishes quickly
#TBH  llq | grep "\.${jobid}\." > /dev/null 2>&1
#TBH  queuestat=$?
#TBH  # wait for job to queue
#TBH  while (( $queuestat != 0 )) ; do
#TBH    sleep ${llq_interval}
#TBH    llq | grep "\.${jobid}\." > /dev/null 2>&1
#TBH    queuestat=$?
#TBH    if (( $queuestat != 0 )) ; then
#TBH      AppendToLogFile "${self}:  waiting for job ${jobid} to queue..." \
#TBH        $self $scriptdir $logfile $email_target
#TBH    fi
#TBH  done

# wait for job to finish
llq | grep "\.${jobid}\." > /dev/null 2>&1
donestat=$?
while (( $donestat == 0 )) ; do
  sleep ${llq_interval}
  llq | grep "\.${jobid}\." > /dev/null 2>&1
  donestat=$?
  if (( $donestat == 0 )) ; then
    AppendToLogFile "${self}:  waiting for job ${jobid} to finish..." \
      $self $scriptdir $logfile $email_target
  fi
done

# HACK just in case stdout and stderr files are not there yet
# sleep 3

exit 0

